#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03-19
#
# Check Point Threat Emulation metrics plugin
# checkpoint_threat_emulation
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info,
)

metric_info['checkpoint_threat_emulation_remaining_quota_on_cloud'] = {
    'title': _('Remaining quota on cloud'),
    'unit': 'count',
    'color': '11/a',
}
metric_info['checkpoint_threat_emulation_monthly_quota_on_cloud_used'] = {
    'title': _('Used monthly quota on cloud'),
    'unit': '%',
    'color': '12/a',
}
metric_info['checkpoint_threat_emulation_current_files_waiting_for_emulation'] = {
    'title': _('Files waiting for emulation'),
    'unit': 'count',
    'color': '13/a',
}

metric_info['checkpoint_threat_emulation_scanned_files_current'] = {
    'title': _('Scanned files (current)'),
    'unit': 'count',
    'color': '14/a',
}

metric_info['checkpoint_threat_emulation_malicious_files_detected_current'] = {
    'title': _('Malicious files detected (current)'),
    'unit': 'count',
    'color': '15/a',
}

metric_info['checkpoint_threat_emulation_files_scanned_by_threat_cloud_current'] = {
    'title': _('Files scanned by threat cloud (current)'),
    'unit': 'count',
    'color': '16/a',
}

metric_info['checkpoint_threat_emulation_malicious_files_detected_by_threat_cloud_current'] = {
    'title': _('Malicious files detected by threat cloud (current)'),
    'unit': 'count',
    'color': '21/a',
}

metric_info['checkpoint_threat_emulation_average_process_time_current'] = {
    'title': _('Average process time (current)'),
    'unit': 's',
    'color': '22/a',
}

metric_info['checkpoint_threat_emulation_average_emulated_file_size_current'] = {
    'title': _('Average emulated file size (current)'),
    'unit': 'bytes',
    'color': '23/a',
}

metric_info['checkpoint_threat_emulation_average_queue_size_current'] = {
    'title': _('Average queue size (current)'),
    'unit': 'count',
    'color': '24/a',
}

metric_info['checkpoint_threat_emulation_peak_queue_size_current'] = {
    'title': _('Peak queue size (current)'),
    'unit': 'count',
    'color': '25/a',
}

graph_info['checkpoint_threat_emulation_remaining_quota_on_cloud'] = {
    'title': _('Check Point Threat Emulation remaining quota on cloud'),
    'metrics': [
        ('checkpoint_threat_emulation_remaining_quota_on_cloud', 'line'),
    ],
    'scalars': [
        ('checkpoint_threat_emulation_remaining_quota_on_cloud:crit'),
        ('checkpoint_threat_emulation_remaining_quota_on_cloud:warn'),
    ],
}
graph_info['checkpoint_threat_emulation_monthly_quota_on_cloud_used'] = {
    'title': _('Check Point Threat Emulation monthly used quota on cloud used'),
    'metrics': [
        ('checkpoint_threat_emulation_monthly_quota_on_cloud_used', 'line'),
    ],
    'scalars': [
        ('checkpoint_threat_emulation_monthly_quota_on_cloud_used:crit'),
        ('checkpoint_threat_emulation_monthly_quota_on_cloud_used:warn'),
    ],
}
graph_info['checkpoint_threat_emulation_current_files_waiting_for_emulation'] = {
    'title': _('Check Point Threat Emulation files waiting for emulation'),
    'metrics': [
        ('checkpoint_threat_emulation_current_files_waiting_for_emulation', 'line'),
    ],
    'scalars': [
        ('checkpoint_threat_emulation_current_files_waiting_for_emulation:crit'),
        ('checkpoint_threat_emulation_current_files_waiting_for_emulation:warn'),
    ],
}
graph_info['checkpoint_threat_emulation_scanned_files_current'] = {
    'title': _('Check Point Threat Emulation scanned files'),
    'metrics': [
        ('checkpoint_threat_emulation_scanned_files_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_malicious_files_detected_current'] = {
    'title': _('Check Point Threat Emulation malicious files detected'),
    'metrics': [
        ('checkpoint_threat_emulation_malicious_files_detected_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_files_scanned_by_threat_cloud_current'] = {
    'title': _('Check Point Threat Emulation files scanned by Threat Cloud'),
    'metrics': [
        ('checkpoint_threat_emulation_files_scanned_by_threat_cloud_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_malicious_files_detected_by_threat_cloud_current'] = {
    'title': _('Check Point Threat Emulation malicious files detected by Threat Cloud'),
    'metrics': [
        ('checkpoint_threat_emulation_malicious_files_detected_by_threat_cloud_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_average_process_time_current'] = {
    'title': _('Check Point Threat Emulation average process time'),
    'metrics': [
        ('checkpoint_threat_emulation_average_process_time_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_average_emulated_file_size_current'] = {
    'title': _('Check Point Threat Emulation average emulated file size'),
    'metrics': [
        ('checkpoint_threat_emulation_average_emulated_file_size_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_average_queue_size_current'] = {
    'title': _('Check Point Threat Emulation average queue size'),
    'metrics': [
        ('checkpoint_threat_emulation_average_queue_size_current', 'line'),
    ],
}
graph_info['checkpoint_threat_emulation_peak_queue_size_current'] = {
    'title': _('Check Point Threat Emulation peak queue size'),
    'metrics': [
        ('checkpoint_threat_emulation_peak_queue_size_current', 'line'),
    ],
}
